pub fn create_file(
path: &str,
access: u32,
share: u32,
disposition: u32,
options: u32,
) -> Vec<u8> ⓘExpand description
Generic disk-file CREATE (2.2.13). path is relative to the connected share root (no
leading backslash). Callers pass the access mask, share mode, disposition, and options.